=======
Credits
=======

Development Lead
----------------

* Eric Goller <eric.goller@ninjaduck.solutions>

Contributors
------------

Code taken from 'legacy hamster'
--------------------------------

* `tbaugis / tstriker <https://github.com/tstriker>`_:
  * ``parse_time_info`` from `hamster-cli <https://github.com/projecthamster/hamster/blob/master/src/hamster-cli>`_
  * ``XMLWriter`` from `hamster <https://github.com/projecthamster/hamster/blame/master/src/hamster/reports.py>`_
